PySceneDetect Documentation — PySceneDetect 0.6.5-dev1 documentation

# PySceneDetect Documentation

Welcome to the PySceneDetect docs. The docs are split into two separate parts: one for the command-line interface (the scenedetect command) and another for the Python API (the scenedetect module).

You can install the latest release of PySceneDetect by running pip install scenedetect[opencv] or downloading the Windows build from scenedetect.com/download. PySceneDetect requires ffmpeg or mkvmerge for video splitting support.

Note

If you see any errors in the documentation, or want to suggest improvements, feel free to raise an issue on the PySceneDetect issue tracker.

PySceneDetect development happens on Github at github.com/Breakthrough/PySceneDetect.

## Table of Contents

### `scenedetect` Command Reference 🖥️

Command-Line Interface:

- `scenedetect` 🎬 Command
- Examples
- Options
  - `help`, `version`, and `about`
- Detectors
  - `detect-adaptive`
  - `detect-content`
  - `detect-hash`
  - `detect-hist`
  - `detect-threshold`
- Commands
  - `export-html`
  - `list-scenes`
  - `load-scenes`
  - `save-images`
  - `split-video`
  - `time`
- Configuration File
  - Example
  - Template
- Backends
  - OpenCV
  - PyAV
  - MoviePy

### `scenedetect` Python Module 🐍

API Documentation:

- `scenedetect` 🎬 Package
  - Getting Started
  - Functions
  - Module Reference
  - Logging
  - Migrating From 0.5
- Detection Algorithms
  - `AdaptiveDetector`
  - `ContentDetector`
  - `HashDetector`
  - `HistogramDetector`
  - `ThresholdDetector`
- Backends
  - Video Files
  - Devices / Cameras / Pipes
  - `AVAILABLE_BACKENDS`
  - `VideoCaptureAdapter`
  - `VideoStreamCv2`
  - `VideoStreamAv`
  - `VideoStreamMoviePy`
- SceneManager
  - Usage
  - Storing Per-Frame Statistics
  - `Interpolation`
  - `SceneManager`
  - `compute_downscale_factor()`
  - `get_scenes_from_cuts()`
  - `save_images()`
  - `write_scene_list()`
  - `write_scene_list_html()`
  - `DEFAULT_MIN_WIDTH`
  - `MAX_FRAME_QUEUE_LENGTH`
  - `MAX_FRAME_SIZE_ERRORS`
  - `PROGRESS_BAR_DESCRIPTION`
- Video Splitting
  - `SceneMetadata`
  - `VideoMetadata`
  - `default_formatter()`
  - `is_ffmpeg_available()`
  - `is_mkvmerge_available()`
  - `split_video_ffmpeg()`
  - `split_video_mkvmerge()`
  - `DEFAULT_FFMPEG_ARGS`
  - `FFMPEG_PATH`
  - `TimecodePair`
  - `test_api_detect()`
  - `test_api_detect_start_end_time()`
  - `test_api_detect_stats()`
  - `test_api_device_callback()`
  - `test_api_scene_manager()`
  - `test_api_scene_manager_callback()`
  - `test_api_scene_manager_start_end_time()`
  - `test_api_stats_manager()`
  - `test_api_timecode_types()`
- StatsManager
  - `StatsFileCorrupt`
  - `StatsManager`
  - `COLUMN_NAME_FRAME_NUMBER`
  - `COLUMN_NAME_TIMECODE`
- FrameTimecode
  - Usage Examples
  - `FrameTimecode`
  - `MAX_FPS_DELTA`
- SceneDetector
  - `SceneDetector`
  - `SparseSceneDetector`
- VideoStream
  - `FrameRateUnavailable`
  - `SeekError`
  - `VideoOpenFailure`
  - `VideoStream`
- Platform & Logging
  - `CommandTooLong`
  - `FakeTqdmLoggingRedirect`
  - `FakeTqdmObject`
  - `Template`
  - `get_and_create_path()`
  - `get_cv2_imwrite_params()`
  - `get_ffmpeg_path()`
  - `get_ffmpeg_version()`
  - `get_file_name()`
  - `get_mkvmerge_version()`
  - `get_system_version_info()`
  - `init_logger()`
  - `invoke_command()`

### Indices and Tables

- Index

- Module Index

- Search Page